Stan Math Library: stan::is_vector_like< T * > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | List of all members
stan::is_vector_like< T * > Struct Template Reference

Template metaprogram indicates whether a type is vector_like. More...

`#include <is_vector_like.hpp>`

## Public Types
enum | { value = true }

## Detailed Description

### template<typename T>
struct stan::is_vector_like< T * >

Template metaprogram indicates whether a type is vector_like.

A type is vector_like if an instance can be accessed like a vector, i.e. square brackets.

A C++ array of T is vector_like.

Template Parameters

  T | Type to test

Definition at line 36 of file is_vector_like.hpp.

## Member Enumeration Documentation

template<typename T >

anonymous enum

Enumerator
value |

Definition at line 37 of file is_vector_like.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/scal/meta/is_vector_like.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.